# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import pulumi
import pulumi.runtime
from .. import utilities, tables

class PersistenceProfileDstAddr(pulumi.CustomResource):
    def __init__(__self__, __name__, __opts__=None, app_service=None, defaults_from=None, hash_algorithm=None, mask=None, match_across_pools=None, match_across_services=None, match_across_virtuals=None, mirror=None, name=None, override_conn_limit=None, timeout=None):
        """Create a PersistenceProfileDstAddr resource with the given unique name, props, and options."""
        if not __name__:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(__name__, str):
            raise TypeError('Expected resource name to be a string')
        if __opts__ and not isinstance(__opts__, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        __props__['app_service'] = app_service

        if not defaults_from:
            raise TypeError('Missing required property defaults_from')
        __props__['defaults_from'] = defaults_from

        __props__['hash_algorithm'] = hash_algorithm

        __props__['mask'] = mask

        __props__['match_across_pools'] = match_across_pools

        __props__['match_across_services'] = match_across_services

        __props__['match_across_virtuals'] = match_across_virtuals

        __props__['mirror'] = mirror

        if not name:
            raise TypeError('Missing required property name')
        __props__['name'] = name

        __props__['override_conn_limit'] = override_conn_limit

        __props__['timeout'] = timeout

        super(PersistenceProfileDstAddr, __self__).__init__(
            'f5bigip:ltm/persistenceProfileDstAddr:PersistenceProfileDstAddr',
            __name__,
            __props__,
            __opts__)


    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop

